==> feastmo-0.34.1.0-py2.py3-none-any.whl: feast/infra/materialization/contrib/bytewax/bytewax_materialization_job.py <==
from typing import Optional

from kubernetes import client

from feast.infra.materialization.batch_materialization_engine import (
    MaterializationJob,
    MaterializationJobStatus,
)


class BytewaxMaterializationJob(MaterializationJob):
    def __init__(
        self,
        job_id,
        namespace,
        error: Optional[BaseException] = None,
    ):
        super().__init__()
        self._job_id = job_id
        self.namespace = namespace
        self._error: Optional[BaseException] = error
        self.batch_v1 = client.BatchV1Api()

    def error(self):
        return self._error

    def status(self):
        if self._error is not None:
            return MaterializationJobStatus.ERROR
        else:
            # TODO: Find a better way to parse status?
            job_status = self.batch_v1.read_namespaced_job_status(
                self.job_id(), self.namespace
            ).status
            if job_status.active is not None:
                if job_status.completion_time is None:
                    return MaterializationJobStatus.RUNNING
            elif job_status.failed is not None:
                self._error = Exception(f"Job {self.job_id()} failed")
                return MaterializationJobStatus.ERROR
            elif job_status.active is None:
                if job_status.completion_time is not None:
                    if job_status.conditions[0].type == "Complete":
                        return MaterializationJobStatus.SUCCEEDED
                return MaterializationJobStatus.WAITING

    def cancel(self):
        self.batch_v1.delete_namespaced_job(
            self.job_id(),
            self.namespace,
        )

    def should_be_retried(self):
        return False

    def job_id(self):
        return f"dataflow-{self._job_id}"

    def url(self):
        return None

==> feastmo-0.36.0.0-py2.py3-none-any.whl: feast/infra/materialization/contrib/bytewax/bytewax_materialization_job.py <==
from typing import Optional

from feast.infra.materialization.batch_materialization_engine import (
    MaterializationJob,
    MaterializationJobStatus,
)
from kubernetes import client


class BytewaxMaterializationJob(MaterializationJob):
    def __init__(
        self,
        job_id,
        namespace,
        error: Optional[BaseException] = None,
    ):
        super().__init__()
        self._job_id = job_id
        self.namespace = namespace
        self._error: Optional[BaseException] = error
        self.batch_v1 = client.BatchV1Api()

    def error(self):
        return self._error

    def status(self):
        if self._error is not None:
            return MaterializationJobStatus.ERROR
        else:
            # TODO: Find a better way to parse status?
            job_status = self.batch_v1.read_namespaced_job_status(
                self.job_id(), self.namespace
            ).status
            if job_status.active is not None:
                if job_status.completion_time is None:
                    return MaterializationJobStatus.RUNNING
            else:
                if (
                    job_status.completion_time is not None
                    and job_status.conditions[0].type == "Complete"
                ):
                    return MaterializationJobStatus.SUCCEEDED

                if (
                    job_status.conditions is not None
                    and job_status.conditions[0].type == "Failed"
                ):
                    self._error = Exception(
                        f"Job {self.job_id()} failed with reason: "
                        f"{job_status.conditions[0].message}"
                    )
                    return MaterializationJobStatus.ERROR
                return MaterializationJobStatus.WAITING

    def cancel(self):
        self.batch_v1.delete_namespaced_job(
            self.job_id(),
            self.namespace,
        )

    def should_be_retried(self):
        return False

    def job_id(self):
        return f"dataflow-{self._job_id}"

    def url(self):
        return None
